===============================
TrelloStats
===============================

.. image:: https://badge.fury.io/py/trellostats.png
    :target: http://badge.fury.io/py/trellostats
    
.. image:: https://travis-ci.org/bwghughes/trellostats.png?branch=master
        :target: https://travis-ci.org/bwghughes/trellostats

.. image:: https://pypip.in/d/trellostats/badge.png
        :target: https://pypi.python.org/pypi/trellostats


Trello Stats for Winners

* Free software: BSD license
* Documentation: http://trellostats.readthedocs.org.

Features
--------

* TODO